import http from "k6/http";
import { group, sleep, check } from "k6";
import { Rate, Trend } from "k6/metrics";

export const options = {
  duration: "2m",
  vus: 5,
  iterations: 5,
};

const params = {
  headers: {
    "X-Disable-Sentry": "true",
  },
};

let checkFailureRate = new Rate("check_failure_rate");
let timeToFirstByte = new Trend("time_to_first_byte", true);

export default function () {
  group("Homepage", function () {
    const res = http.get("https://staging.dev.holi.social", params);

    let checkRes = check(res, {
      "is status 200": (r) => r.status === 200,
    });

    // Record check failures
    checkFailureRate.add(!checkRes);

    // Record time to first byte and tag it with the URL to be able to filter the results in Insights
    timeToFirstByte.add(res.timings.waiting, { ttfbURL: res.url });

    sleep(Math.random() * 5);
  });
}
